x_storage_core library

Classes

AssetStorageProvider
Flutter アセットから読み書きするためのプロバイダ (アセットへの書き込みや削除はサポートされない)
XFileHead
Metadata about a stored file, retrieved without downloading its contents.
XStorage
The main XStorage class
XStorageProvider
Abstract base class for storage providers

Enums

SyncStatus
同期ステータス
XStorageType
Enum representing the type of storage

Mixins

AssetProviderMixin
Mixin for asset-based storage providers
CachingProviderMixin
キャッシュ機能を持つプロバイダーのインターフェース
FileProviderMixin
Mixin for file system-based storage providers
NetworkProviderMixin
Mixin for network-based storage providers
SyncProviderMixin
ローカルが正、リモートがバックアップ/同期先となるプロバイダーのインターフェース

Extension Types

XUri
An extension type that wraps Uri to provide simplified creation methods for storage URIs.

Exceptions / Errors

FileNotFoundException
ファイルが見つからない場合のエラー
ProviderNotFoundException
プロバイダが見つからない場合のエラー
UnknownException
その他のエラー
UnsupportedOperationException
操作が未サポートの場合のエラー
XStorageException
ストレージ操作に関するエラー